package ittp.protocol.response.headers;

import ittp.protocol.response.Response;
import ittp.protocol.request.Request;
import java.util.HashSet;
import java.util.Set;
import java.util.Iterator;

/**
 * This class create the header content-MD5.
 * @author Frederic Bidon and Mathieu Texier
 */
public class ContentType  extends Response.Headers{
    private Response parent;
    private Set type;
    /**Constructor of the class*/
    public ContentType (Response parent) {
        parent.super ();
        this.parent = parent;
        type = new HashSet ();
        /**Declaration of the combination between the type and subtype of the suffix from the filename.*/
        type.add (new Type (".html", "text/html"));
        type.add (new Type (".htm", "text/html"));
        type.add (new Type (".txt", "text/txt"));
        type.add (new Type (".gif", "image/gif"));
        type.add (new Type (".jpg", "image/jpeg"));
        type.add (new Type (".jpeg", "image/jpeg"));
        type.add (new Type ("TRACE", "message/ittp"));
    }
    
    /**
     * Determine the type of the body according to the suffix found.
     * Convert to a string the headers content-type.
     * @return a string containing the content-type of the body.
     */
    public String toString () {
        Iterator it = type.iterator ();
        while (it.hasNext ()) {
            Type t = (Type) it.next ();
            String path = parent.body.getPathName ();
            if (path.endsWith (t.suffix))
                return t.mediaType + "\n";
        }
        return "application/octet-stream\n";
    }
    
    /**
     * Mutators for the boolean allowed.
     * @param allowed boolean that determine if this headers is allowed.
     */
    public void setAllowed (boolean allowed) {
        this.allowed = allowed;
    }
    
    /**
     * Mutators for the boolean used.
     * @param used boolean that determine if this headers is used.
     */
    public void setUsed (boolean used) {
        this.used = used;
    }
    
    /**
     * This class allow to determine the type of the ressource.
     */
    private class Type {
        private String suffix;
        private String mediaType;
        
        /**
         * Constructor of the class Type.
         * @param suffix: String containing th suffix of the name of the body.
         * @param mediaType: String containing the media type of the body.
         */
        Type (String suffix, String mediaType) {
            this.suffix = suffix;
            this.mediaType = mediaType;
        }
        
        /**
         * Convert to a string the headers content-type.
         * @return a string containing the suffix and the media type of the body.
         */
        public String toString () {
            return  "suffix : " + suffix + "mediaType : " + mediaType;
        }
    }
}