package ittp.protocol.request.headers;

import ittp.protocol.request.Request;
import ittp.ittpException;
import ittp.protocol.response.Response;
import java.net.InetAddress;
import java.net.UnknownHostException;

/**
 * This class analyse the header host send by the client.
 * @author Frederic Bidon and Mathieu Texier
 */
public class Host extends Request.Headers{
    private String hostName;
    private boolean used = false;
    private Request parent;
    /**Constructor of the class*/
    public Host (Request parent) {
        parent.super ();
        this.parent = parent;
    }
    
    /**
     * Mutators for the String hostName.
     * @param hostName String that contain the name of the host.
     * @throws ittpException if the host already exist or if the host does not match.
     */
    public void setHostName (String hostName) throws ittpException {
        if (used)
            throw new ittpException ("headers Host already received", Response.Code.ITTP_BAD_REQUEST);
        
        InetAddress ip = parent.toIP(hostName);
        if (ip == null)
            throw new ittpException("nonvalide IP address or host " + ittp.Server.getIP(), Response.Code.ITTP_NOT_FOUND);
        if (!ip.equals(parent.getIP()) && !hostName.toLowerCase ().equals("localhost"))
            throw new ittpException("IP address does not match " + ittp.Server.getIP(), Response.Code.ITTP_NOT_FOUND);

        this.hostName = hostName;
        used = true;
    }
    
    /**
     * Accessors for the String hostName.
     * @return hostName: String that the name of the host.
     */
    public String getHostName () {
        return hostName;
    }
    
    /**
     * Convert to a string the headers date send by the client.
     * @return a string containing the response to this headers if it is used.
     */
    public String toString () {
        if (used)
            return hostName + "\n";
        else return "";
    }
    
    /**
     * Accessors for the boolean used.
     * @return used: boolean that determine if this headers is used.
     */
    public boolean isUsed () {
        return used;
    }
}
